@@ -6,6 +6,7 @@ import (
 	"strconv"
 	"strings"
 	"unicode"
+	"unicode/utf8"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
@@ -38,6 +39,10 @@ func (f Folders) List() []string {
 	return list
 }
 
+func (f Folders) Last() *Folder {
+	return f[len(f)-1]
+}
+
 type Path struct {
 	base
 
@@ -120,6 +125,12 @@ const (
 	DisplayCygpath properties.Property = "display_cygpath"
 	// DisplayRoot indicates if the linux root slash should be displayed
 	DisplayRoot properties.Property = "display_root"
+	// Fish displays the path in a fish-like style
+	Fish string = "fish"
+	// DirLength the length of the directory name to display in fish style
+	DirLength properties.Property = "dir_length"
+	// FullLengthDirs indicates how many full length directory names should be displayed in fish style
+	FullLengthDirs properties.Property = "full_length_dirs"
 )
 
 func (pt *Path) Template() string {
@@ -161,7 +172,10 @@ func (pt *Path) setPaths() {
 
 	pt.cygPath = displayCygpath()
 	pt.windowsPath = pt.env.GOOS() == runtime.WINDOWS && !pt.cygPath
-	pt.pathSeparator = path.Separator()
+
+	if len(pt.pathSeparator) == 0 {
+		pt.pathSeparator = path.Separator()
+	}
 
 	pt.pwd = pt.env.Pwd()
 	if (pt.env.Shell() == shell.PWSH || pt.env.Shell() == shell.PWSH5) && len(pt.env.Flags().PSWD) != 0 {
@@ -219,7 +233,8 @@ func (pt *Path) setStyle() {
 
 	switch style := pt.props.GetString(properties.Style, Agnoster); style {
 	case Agnoster:
-		pt.Path = pt.getAgnosterPath()
+		maxWidth := pt.getMaxWidth()
+		pt.Path = pt.getAgnosterPath(maxWidth)
 	case AgnosterFull:
 		pt.Path = pt.getAgnosterFullPath()
 	case AgnosterShort:
@@ -239,6 +254,8 @@ func (pt *Path) setStyle() {
 	case Powerlevel:
 		maxWidth := pt.getMaxWidth()
 		pt.Path = pt.getUniqueLettersPath(maxWidth)
+	case Fish:
+		pt.Path = pt.getFishPath()
 	default:
 		pt.Path = fmt.Sprintf("Path style: %s is not available", style)
 	}
@@ -330,7 +347,11 @@ func (pt *Path) getMixedPath() string {
 	return pt.colorizePath(root, elements)
 }
 
-func (pt *Path) getAgnosterPath() string {
+func (pt *Path) getAgnosterPath(maxWidth int) string {
+	if maxWidth > 0 {
+		return pt.getAgnosterMaxWidth(maxWidth)
+	}
+
 	folderIcon := pt.props.GetString(FolderIcon, "..")
 
 	root, folders := pt.getPaths()
@@ -415,6 +436,34 @@ func (pt *Path) getLetterPath() string {
 	return pt.colorizePath(root, elements)
 }
 
+func (pt *Path) getFishPath() string {
+	root, folders := pt.getPaths()
+	folders = append(Folders{&Folder{Name: root, Display: false}}, folders...)
+
+	dirLength := pt.props.GetInt(DirLength, 1)
+	fullLengthDirs := max(pt.props.GetInt(FullLengthDirs, 1), 1)
+
+	folderCount := len(folders)
+	stopAt := folderCount - fullLengthDirs
+
+	var elements []string
+	for i := range folderCount {
+		name := folders[i].Name
+		if folders[i].Display || dirLength <= 0 || len(name) < dirLength || i >= stopAt {
+			elements = append(elements, name)
+			continue
+		}
+
+		elements = append(elements, name[:dirLength])
+	}
+
+	if len(elements) == 1 {
+		return pt.colorizePath(elements[0], nil)
+	}
+
+	return pt.colorizePath(elements[0], elements[1:])
+}
+
 func (pt *Path) getUniqueLettersPath(maxWidth int) string {
 	dr := pt.props.GetBool(DisplayRoot, false)
 	log.Debugf("%t", dr)
@@ -480,6 +529,43 @@ func (pt *Path) getUniqueLettersPath(maxWidth int) string {
 	return pt.colorizePath(root, elements)
 }
 
+func (pt *Path) getAgnosterMaxWidth(maxWidth int) string {
+	separator := pt.getFolderSeparator()
+	folderIcon := pt.props.GetString(FolderIcon, "..")
+
+	root, folders := pt.getPaths()
+	folderNames := append([]string{root}, folders.List()...)
+
+	// this assumes that the root is never a single character
+	// except when it really is / on unix systems
+	if len(root) == 1 {
+		maxWidth++ // add one for the separator
+	}
+
+	if len(folderNames) == 0 {
+		return pt.colorizePath(root, nil)
+	}
+
+	fullPath := strings.Join(folderNames, separator)
+
+	for i := 0; i < len(folderNames)-1 && utf8.RuneCountInString(fullPath) > maxWidth; i++ {
+		folderNames[i] = folderIcon
+		fullPath = strings.Join(folderNames, separator)
+	}
+
+	for len(folderNames) > 1 && utf8.RuneCountInString(fullPath) > maxWidth {
+		// remove every folder until the path is short enough
+		folderNames = folderNames[1:]
+		fullPath = strings.Join(folderNames, separator)
+	}
+
+	if len(folderNames) == 1 {
+		return pt.colorizePath(template.TruncE(maxWidth, folderNames[0]), nil)
+	}
+
+	return pt.colorizePath(folderNames[0], folderNames[1:])
+}
+
 func (pt *Path) getAgnosterFullPath() string {
 	root, folders := pt.getPaths()
 
@@ -489,10 +575,7 @@ func (pt *Path) getAgnosterFullPath() string {
 func (pt *Path) getAgnosterShortPath() string {
 	root, folders := pt.getPaths()
 
-	maxDepth := pt.props.GetInt(MaxDepth, 1)
-	if maxDepth < 1 {
-		maxDepth = 1
-	}
+	maxDepth := max(pt.props.GetInt(MaxDepth, 1), 1)
 
 	pathDepth := len(folders)
 	hideRootLocation := pt.props.GetBool(HideRootLocation, false)
@@ -741,7 +824,7 @@ func (pt *Path) getPaths() (string, Folders) {
 		return len(inputPath) == 1 && path.IsSeparator(inputPath[0])
 	}
 
-	if isRootFS(root) {
+	if isRootFS(root) && len(folders) > 0 {
 		root = folders[0].Name
 		folders = folders[1:]
 	}
@@ -770,6 +853,10 @@ func (pt *Path) normalize(inputPath string) string {
 		normalized = strings.ToLower(normalized)
 	}
 
+	if pt.cygPath {
+		return strings.ReplaceAll(normalized, `\`, "/")
+	}
+
 	return normalized
 }
 
