@@ -3,12 +3,7 @@ package template
 import (
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/cache"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
-
 	"github.com/stretchr/testify/assert"
-	testify_ "github.com/stretchr/testify/mock"
 )
 
 func TestRoundSeconds(t *testing.T) {
@@ -29,20 +24,10 @@ func TestRoundSeconds(t *testing.T) {
 		{Case: "error", Expected: "", Template: "{{ secondsRound foo }}", ShouldError: true},
 	}
 
-	env := &mock.Environment{}
-	env.On("TemplateCache").Return(&cache.Template{
-		Env: make(map[string]string),
-	})
-	env.On("Error", testify_.Anything)
-	env.On("Debug", testify_.Anything)
-	env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
-	env.On("Flags").Return(&runtime.Flags{})
-
 	for _, tc := range cases {
 		tmpl := &Text{
 			Template: tc.Template,
 			Context:  nil,
-			Env:      env,
 		}
 
 		text, err := tmpl.Render()
