@@ -7,6 +7,8 @@ import (
 	"io"
 	"os"
 	"path/filepath"
+
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 )
 
 func install(cfg *Config) error {
@@ -14,6 +16,7 @@ func install(cfg *Config) error {
 
 	executable, err := os.Executable()
 	if err != nil {
+		log.Debug("failed to get executable path")
 		return err
 	}
 
@@ -23,6 +26,7 @@ func install(cfg *Config) error {
 	newPath := filepath.Join(targetDir, fmt.Sprintf(".%s.new", fileName))
 	fp, err := os.OpenFile(newPath, os.O_CREATE|os.O_WRONLY|os.O_TRUNC, 0775)
 	if err != nil {
+		log.Error(err)
 		return errors.New("we do not have permissions to update")
 	}
 
@@ -30,6 +34,7 @@ func install(cfg *Config) error {
 
 	data, err := downloadAndVerify(cfg)
 	if err != nil {
+		log.Debug("failed to download and verify")
 		return err
 	}
 
@@ -40,6 +45,7 @@ func install(cfg *Config) error {
 	fp.Close()
 
 	if err != nil {
+		log.Debug("failed to copy data to new file")
 		return err
 	}
 
@@ -49,15 +55,18 @@ func install(cfg *Config) error {
 
 	err = os.Rename(executable, oldPath)
 	if err != nil {
+		log.Debug("failed to rename old file")
 		return err
 	}
 
 	err = os.Rename(newPath, executable)
 
 	if err != nil {
+		log.Debug("failed to rename new file, rolling back")
 		// rollback
 		rerr := os.Rename(oldPath, executable)
 		if rerr != nil {
+			log.Debug("failed to rollback old file")
 			return rerr
 		}
 
@@ -68,6 +77,8 @@ func install(cfg *Config) error {
 
 	// hide the old executable if we can't remove it
 	if removeErr != nil {
+		log.Error(removeErr)
+		// hide the old executable
 		_ = hideFile(oldPath)
 	}
 
